==> kubernetes-model-kustomize-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/SourceSelectorFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SourceSelectorFluent<A extends SourceSelectorFluent<A>> extends Fluent<A>{
  public String getFieldPath();
  public A withFieldPath(String fieldPath);
  public Boolean hasFieldPath();
  public String getGroup();
  public A withGroup(String group);
  public Boolean hasGroup();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getNamespace();
  public A withNamespace(String namespace);
  public Boolean hasNamespace();
  
  /**
   * This method has been deprecated, please use method buildOptions instead.
   * @return The buildable object.
   */
  @Deprecated
  public FieldOptions getOptions();
  public FieldOptions buildOptions();
  public A withOptions(FieldOptions options);
  public Boolean hasOptions();
  public A withNewOptions(Boolean create,String delimiter,String encoding,Integer index);
  public SourceSelectorFluent.OptionsNested<A> withNewOptions();
  public SourceSelectorFluent.OptionsNested<A> withNewOptionsLike(FieldOptions item);
  public SourceSelectorFluent.OptionsNested<A> editOptions();
  public SourceSelectorFluent.OptionsNested<A> editOrNewOptions();
  public SourceSelectorFluent.OptionsNested<A> editOrNewOptionsLike(FieldOptions item);
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface OptionsNested<N> extends Nested<N>,FieldOptionsFluent<SourceSelectorFluent.OptionsNested<N>>{
    public N and();
    public N endOptions();
    
  }
  
}

==> kubernetes-model-kustomize-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/SourceSelectorFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SourceSelectorFluent<A extends SourceSelectorFluent<A>> extends Fluent<A>{
  public String getFieldPath();
  public A withFieldPath(String fieldPath);
  public Boolean hasFieldPath();
  public String getGroup();
  public A withGroup(String group);
  public Boolean hasGroup();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getNamespace();
  public A withNamespace(String namespace);
  public Boolean hasNamespace();
  
  /**
   * This method has been deprecated, please use method buildOptions instead.
   * @return The buildable object.
   */
  @Deprecated
  public FieldOptions getOptions();
  public FieldOptions buildOptions();
  public A withOptions(FieldOptions options);
  public Boolean hasOptions();
  public A withNewOptions(Boolean create,String delimiter,String encoding,Integer index);
  public SourceSelectorFluent.OptionsNested<A> withNewOptions();
  public SourceSelectorFluent.OptionsNested<A> withNewOptionsLike(FieldOptions item);
  public SourceSelectorFluent.OptionsNested<A> editOptions();
  public SourceSelectorFluent.OptionsNested<A> editOrNewOptions();
  public SourceSelectorFluent.OptionsNested<A> editOrNewOptionsLike(FieldOptions item);
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface OptionsNested<N> extends Nested<N>,FieldOptionsFluent<SourceSelectorFluent.OptionsNested<N>>{
    public N and();
    public N endOptions();
    
  }
  
}
